==> foundation-2.6.1.tgz: package/TorsoBusiness/TorsoBusiness.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const TorsoBusiness = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.161 60.441l-15.66-7.47-6.622-3.159c2.892-1.822 5.241-4.634 6.778-8.021a21.743 21.743 0 001.945-8.99c0-1.827-.29-3.562-.694-5.236-1.97-8.112-8.305-14.088-15.91-14.088-7.461 0-13.7 5.763-15.792 13.644-.483 1.808-.815 3.688-.815 5.68 0 3.459.808 6.684 2.181 9.489 1.587 3.254 3.94 5.937 6.804 7.662l-6.342 2.953-16.168 7.53c-1.404.658-2.327 2.242-2.327 4.011v17.765c0 2.381 1.659 4.311 3.707 4.311h24.013V72.92a.78.78 0 01.119-.396l-.01-.006 3.933-6.812.01.006c.14-.24.389-.41.687-.41.298 0 .547.169.687.41l.004-.003.036.063c.005.01.012.018.016.028l3.881 6.721-.005.003a.783.783 0 01.119.397v13.602h24.013c2.048 0 3.708-1.93 3.708-4.311V64.446c.003-1.763-.905-3.332-2.296-4.005zM54.62 55.886l.01.006-3.934 6.812-.01-.006a.796.796 0 01-.687.409.796.796 0 01-.687-.409l-.005.003-.04-.069c-.003-.007-.009-.013-.012-.02l-3.881-6.723.004-.003a.783.783 0 01-.119-.397c0-.445.361-.806.806-.806h7.866c.445 0 .806.361.806.806a.762.762 0 01-.117.397z"
  }));
});
TorsoBusiness.displayName = 'TorsoBusiness';
export const TorsoBusinessDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/TorsoBusiness/TorsoBusiness.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var TorsoBusiness = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.161 60.441l-15.66-7.47-6.622-3.159c2.892-1.822 5.241-4.634 6.778-8.021a21.743 21.743 0 001.945-8.99c0-1.827-.29-3.562-.694-5.236-1.97-8.112-8.305-14.088-15.91-14.088-7.461 0-13.7 5.763-15.792 13.644-.483 1.808-.815 3.688-.815 5.68 0 3.459.808 6.684 2.181 9.489 1.587 3.254 3.94 5.937 6.804 7.662l-6.342 2.953-16.168 7.53c-1.404.658-2.327 2.242-2.327 4.011v17.765c0 2.381 1.659 4.311 3.707 4.311h24.013V72.92a.78.78 0 01.119-.396l-.01-.006 3.933-6.812.01.006c.14-.24.389-.41.687-.41.298 0 .547.169.687.41l.004-.003.036.063c.005.01.012.018.016.028l3.881 6.721-.005.003a.783.783 0 01.119.397v13.602h24.013c2.048 0 3.708-1.93 3.708-4.311V64.446c.003-1.763-.905-3.332-2.296-4.005zM54.62 55.886l.01.006-3.934 6.812-.01-.006a.796.796 0 01-.687.409.796.796 0 01-.687-.409l-.005.003-.04-.069c-.003-.007-.009-.013-.012-.02l-3.881-6.723.004-.003a.783.783 0 01-.119-.397c0-.445.361-.806.806-.806h7.866c.445 0 .806.361.806.806a.762.762 0 01-.117.397z"
  }));
});
TorsoBusiness.displayName = 'TorsoBusiness';
export var TorsoBusinessDimensions = {
  height: 100,
  width: 100
};
